import { useState } from 'react'
import { Button, Empty, Flex, Modal } from 'antd'
import { useNavigate } from 'react-router'
import AppSteps from '@/components/AppSteps'

import { useAIStore } from '@/ai/useAIStore'
import prompt from '@/ai/prompt'

interface ResultItem {
  line: number
  lines: number[]
  desc: string
}

export default function ButtonModal() {
  const [results, setResults] = useState<ResultItem[]>([])

  const isLoading = useAIStore((state) => state.isLoading)
  const post = useAIStore((state) => state.post)

  const handleAI = async () => {
    const message = await post({
      response_format: { type: 'json_object' },
      messages: [{ role: 'user', content: prompt.repeat }],
    })
    console.log(message.json)
    if (message.json && Array.isArray(message.json.results)) {
      setResults(message.json.results)
    }
  }

  const navigate = useNavigate()
  const [open, setOpen] = useState(false)
  const [current, setCurrent] = useState(0)

  const next = () => {
    setCurrent(current + 1)
  }

  const prev = () => {
    setCurrent(current - 1)
  }

  const steps = [{ title: '探索重复值' }, { title: '处理重复值' }]

  return (
    <>
      <Button type="primary" onClick={() => setOpen(true)}>
        重复值
      </Button>
      <Modal
        title="重复值探索"
        open={open}
        footer={
          <Flex justify="center" gap={20}>
            {current === 0 && (
              <Button type="primary" loading={isLoading} onClick={handleAI}>
                智能探索重复值字段
              </Button>
            )}
            {current > 0 && <Button onClick={() => prev()}>上一步</Button>}
            {current < steps.length - 1 && (
              <Button type="primary" onClick={() => next()} disabled={!results.length}>
                下一步
              </Button>
            )}
            {current === steps.length - 1 && (
              <Button
                type="primary"
                onClick={() =>
                  navigate({ pathname: '/data/preprocess/repeat', search: `?results=${JSON.stringify(results)}` })
                }>
                跳转数据预处理
              </Button>
            )}
          </Flex>
        }
        destroyOnClose
        width={800}
        onCancel={() => setOpen(false)}>
        <div style={{ minHeight: 300, padding: '40px 0' }}>
          <AppSteps current={current} items={steps} style={{ marginBottom: 40 }} />
          <Flex justify="space-between" style={{ marginBottom: 20 }}>
            探索结果：
          </Flex>
          {results.map((item, index) => (
            <p key={index}>
              {index + 1}、 {item.desc}
            </p>
          ))}
          {!results.length && <Empty></Empty>}
        </div>
      </Modal>
    </>
  )
}
