import DataWrap from '@/components/data/DataWrap'
import { Button, message } from 'antd'
import { useAIStore } from '@/ai/useAIStore'

export default function DataWriteUpload() {
  const [messageApi, contextHolder] = message.useMessage()
  const post = useAIStore((state) => state.post)

  async function handleClick(type: number) {
    messageApi.open({ type: 'loading', content: '数据正在智能分析中，请您耐心等待', duration: 0 })
    if (type == 1) {
      await post({
        messages: [
          {
            role: 'user',
            content: `请基于提供的数据集，为每个字段生成结构化说明，需包含以下要素：

字段名称及定义

数据类型（如字符串/数值/时间戳等）

示例值展示

业务场景中的实际含义

数据采集来源说明（如可识别）

请以表格形式呈现，重点字段用★标注，并指出可能存在的数据异常情况`,
          },
        ],
      })
    } else {
      await post({
        messages: [
          {
            role: 'user',
            content: `作为数据分析专家，请基于提供的数据集，系统分析字段间的业务逻辑关系，

需包含： 

1、核心业务流程图（订单-支付-物流-售后全链路） 

2、关键字段的依赖关系（如：单价×销量=销售额） 

3、业务规则验证（如优惠金额与实际付款的校验逻辑） 

4、异常数据关联模式（如交易状态与物流状态矛盾案例） 

【输出要求】 语言：中文口语化，禁用复杂术语`,
          },
        ],
      })
    }

    messageApi.destroy()
  }

  return (
    <DataWrap
      title="数据理解"
      buttons={
        <>
          {contextHolder}
          <Button type="primary" onClick={() => handleClick(1)}>
            一键理解数据字段
          </Button>
          <Button type="primary" onClick={() => handleClick(2)}>
            一键梳理字段关系
          </Button>
        </>
      }></DataWrap>
  )
}
